@@ -531,6 +531,21 @@ func TestBreakdownTerragruntHCLModuleOutputForEach(t *testing.T) {
 	)
 }
 
+func TestBreakdownTerragruntDiffProjectError(t *testing.T) {
+	projectPath := path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName())
+
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"diff",
+			"--path", projectPath,
+			"--compare-to", path.Join(projectPath, "prior.json"),
+		},
+		&GoldenFileOptions{CaptureLogs: true},
+	)
+}
+
 func TestBreakdownTerragruntGetEnv(t *testing.T) {
 	os.Setenv("CUSTOM_OS_VAR", "test")
 	os.Setenv("CUSTOM_OS_VAR_PROD", "test-prod")
@@ -1054,6 +1069,32 @@ func TestBreakdownWithPolicyDataUploadHCL(t *testing.T) {
 	testutil.AssertGoldenFile(t, path.Join("./testdata", testName, testName+"-upload.golden"), uploadWriter.Bytes())
 }
 
+func TestBreakdownWithMockedMerge(t *testing.T) {
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--path",
+			path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName()),
+		},
+		nil,
+	)
+}
+
+func TestBreakdownWithDynamicIterator(t *testing.T) {
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--path",
+			path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName()),
+		},
+		nil,
+	)
+}
+
 func TestBreakdownWithPolicyDataUploadPlanJson(t *testing.T) {
 	ts, uploadWriter := GraphqlTestServerWithWriter(map[string]string{
 		"policyResourceAllowList": policyResourceAllowlistGraphQLResponse,
