@@ -47,11 +47,14 @@ See https://infracost.io/docs/features/cli_commands/#upload-runs`,
 			if ctx.Config.PolicyV2APIEndpoint != "" {
 				policyClient, err := apiclient.NewPolicyAPIClient(ctx)
 				if err != nil {
-					logging.Logger.WithError(err).Error("Failed to initialize policies client")
+					logging.Logger.Err(err).Msg("Failed to initialize policies client")
 				} else {
-					policies, err := policyClient.CheckPolicies(ctx, root)
+					// If there is a PR ID, only check policies on modified resources (onlyDiff = true). It there
+					// isn't a PR ID it must be a base branch run so all resources are checked.
+					onlyDiff := root.Metadata.VCSPullRequestID != ""
+					policies, err := policyClient.CheckPolicies(ctx, root, onlyDiff)
 					if err != nil {
-						logging.Logger.WithError(err).Error("Failed to check policies")
+						logging.Logger.Err(err).Msg("Failed to check policies")
 					}
 
 					root.TagPolicies = policies.TagPolicies
@@ -74,7 +77,7 @@ See https://infracost.io/docs/features/cli_commands/#upload-runs`,
 			pricingClient := apiclient.GetPricingAPIClient(ctx)
 			err = pricingClient.AddEvent("infracost-upload", ctx.EventEnv())
 			if err != nil {
-				logging.Logger.WithError(err).Warn("could not report `infracost-upload` event")
+				logging.Logger.Warn().Err(err).Msg("could not report `infracost-upload` event")
 			}
 
 			if len(result.GovernanceFailures) > 0 {
