@@ -11,7 +11,7 @@ import (
 
 	"github.com/google/uuid"
 	"github.com/pkg/errors"
-	log "github.com/sirupsen/logrus"
+	"github.com/rs/zerolog/log"
 	"github.com/tidwall/gjson"
 
 	"github.com/infracost/infracost/internal/logging"
@@ -30,24 +30,36 @@ type GraphQLQuery struct {
 	Variables map[string]interface{} `json:"variables"`
 }
 
+var (
+	ErrorCodeExceededQuota = "above_quota"
+	ErrorCodeAPIKeyInvalid = "invalid_api_key"
+)
+
+// APIError defines an api error that is designed to be showed to the user in a
+// output form (comment/stdout/html).
 type APIError struct {
 	err error
-	msg string
+	// Msg defines a human-readable string that is safe to show to the user
+	// to give more context about an error.
+	Msg string
+	// Code is the original StatusCode of the error.
+	Code int
+	// ErrorCode is the internal error code that can accompany errors from different status codes.
+	ErrorCode string
 }
 
 func (e *APIError) Error() string {
-	return fmt.Sprintf("%s: %v", e.msg, e.err.Error())
+	return fmt.Sprintf("%s: %v", e.Msg, e.err.Error())
 }
 
 type APIErrorResponse struct {
-	Error string `json:"error"`
+	Error     string `json:"error"`
+	ErrorCode string `json:"error_code"`
 }
 
-var ErrInvalidAPIKey = errors.New("Invalid API key")
-
 func (c *APIClient) doQueries(queries []GraphQLQuery) ([]gjson.Result, error) {
 	if len(queries) == 0 {
-		log.Debug("Skipping GraphQL request as no queries have been specified")
+		log.Debug().Msg("Skipping GraphQL request as no queries have been specified")
 		return []gjson.Result{}, nil
 	}
 
@@ -56,7 +68,7 @@ func (c *APIClient) doQueries(queries []GraphQLQuery) ([]gjson.Result, error) {
 }
 
 func (c *APIClient) doRequest(method string, path string, d interface{}) ([]byte, error) {
-	logging.Logger.Debugf("'%s' request to '%s' using trace_id: '%s'", method, path, c.uuid.String())
+	logging.Logger.Debug().Msgf("'%s' request to '%s' using trace_id: '%s'", method, path, c.uuid.String())
 
 	reqBody, err := json.Marshal(d)
 	if err != nil {
@@ -83,7 +95,7 @@ func (c *APIClient) doRequest(method string, path string, d interface{}) ([]byte
 
 	respBody, err := io.ReadAll(resp.Body)
 	if err != nil {
-		return []byte{}, &APIError{err, fmt.Sprintf("Invalid API response %s %s", method, path)}
+		return []byte{}, &APIError{err: err, Msg: fmt.Sprintf("Invalid API response %s %s", method, path)}
 	}
 
 	if resp.StatusCode != 200 {
@@ -91,13 +103,19 @@ func (c *APIClient) doRequest(method string, path string, d interface{}) ([]byte
 
 		err = json.Unmarshal(respBody, &r)
 		if err != nil {
-			return []byte{}, &APIError{err, fmt.Sprintf("Invalid API response %q %q body: %q", method, path, respBody)}
+			return []byte{}, &APIError{err: err, Msg: fmt.Sprintf("Invalid API response %q %q body: %q", method, path, respBody), Code: resp.StatusCode}
 		}
 
-		if r.Error == "Invalid API key" {
-			return []byte{}, ErrInvalidAPIKey
+		if r.ErrorCode != "" {
+			return []byte{}, &APIError{err: fmt.Errorf("%v %v", resp.Status, r.Error), Msg: r.Error, Code: resp.StatusCode, ErrorCode: r.ErrorCode}
 		}
-		return []byte{}, &APIError{fmt.Errorf("%v %v", resp.Status, r.Error), "Received error from API"}
+
+		// handle legacy cloud pricing apis which don't have the new `error_code` field.
+		if r.Error == "Invalid API key" {
+			return []byte{}, &APIError{err: fmt.Errorf("%v %v", resp.Status, r.Error), Msg: "Invalid API Key", Code: resp.StatusCode, ErrorCode: ErrorCodeAPIKeyInvalid}
+		}
+
+		return []byte{}, &APIError{err: fmt.Errorf("%v %v", resp.Status, r.Error), Msg: "Received error from API", Code: resp.StatusCode}
 	}
 
 	return respBody, nil
