@@ -8,7 +8,7 @@ import (
 	json "github.com/json-iterator/go"
 
 	"github.com/pkg/errors"
-	log "github.com/sirupsen/logrus"
+	"github.com/rs/zerolog/log"
 
 	"github.com/infracost/infracost/internal/config"
 	"github.com/infracost/infracost/internal/output"
@@ -139,7 +139,7 @@ func (c *DashboardAPIClient) AddRun(ctx *config.RunContext, out output.Root, com
 	}
 
 	q := `
-	mutation($run: RunInput!, $commentFormat: CommentFormat!) {
+	mutation AddRun($run: RunInput!, $commentFormat: CommentFormat!) {
 			addRun(run: $run) {
 				id
 				shareUrl
@@ -181,7 +181,7 @@ func (c *DashboardAPIClient) AddRun(ctx *config.RunContext, out output.Root, com
 		successMsg := fmt.Sprintf("Estimate uploaded to %sInfracost Cloud", orgMsg)
 
 		if ctx.Config.IsLogging() {
-			log.Info(successMsg)
+			log.Info().Msg(successMsg)
 		} else {
 			fmt.Fprintf(ctx.ErrWriter, "%s\n", successMsg)
 		}
@@ -220,7 +220,7 @@ func (c *DashboardAPIClient) AddRun(ctx *config.RunContext, out output.Root, com
 
 func outputGovernanceMessages(ctx *config.RunContext, msg string) {
 	if ctx.Config.IsLogging() {
-		log.Infof(msg)
+		log.Info().Msg(msg)
 	} else {
 		fmt.Fprintf(ctx.ErrWriter, "%s\n", msg)
 	}
