@@ -30,7 +30,7 @@ type PolicyAPIClient struct {
 // NewPolicyAPIClient retrieves resource allow-list info from Infracost Cloud and returns a new policy client
 func NewPolicyAPIClient(ctx *config.RunContext) (*PolicyAPIClient, error) {
 	client := retryablehttp.NewClient()
-	client.Logger = &LeveledLogger{Logger: logging.Logger.WithField("library", "retryablehttp")}
+	client.Logger = &LeveledLogger{Logger: logging.Logger.With().Str("library", "retryablehttp").Logger()}
 	c := PolicyAPIClient{
 		APIClient: APIClient{
 			httpClient: client.StandardClient(),
@@ -48,15 +48,15 @@ type PolicyOutput struct {
 	FinOpsPolicies []output.FinOpsPolicy
 }
 
-func (c *PolicyAPIClient) CheckPolicies(ctx *config.RunContext, out output.Root) (*PolicyOutput, error) {
+func (c *PolicyAPIClient) CheckPolicies(ctx *config.RunContext, out output.Root, onlyDiff bool) (*PolicyOutput, error) {
 	ri, err := newRunInput(ctx, out)
 	if err != nil {
 		return nil, err
 	}
 
 	q := `
-		query($run: RunInput!) {
-			evaluatePolicies(run: $run) {
+		query EvaluatePolicies($run: RunInput!, $onlyDiff: Boolean) {
+			evaluatePolicies(run: $run, onlyDiff: $onlyDiff) {
 				tagPolicyResults {
 					name
 					tagPolicyId
@@ -108,7 +108,8 @@ func (c *PolicyAPIClient) CheckPolicies(ctx *config.RunContext, out output.Root)
 	`
 
 	v := map[string]interface{}{
-		"run": *ri,
+		"run":      *ri,
+		"onlyDiff": onlyDiff,
 	}
 	results, err := c.doQueries([]GraphQLQuery{{q, v}})
 	if err != nil {
@@ -134,39 +135,7 @@ func (c *PolicyAPIClient) CheckPolicies(ctx *config.RunContext, out output.Root)
 
 	err = json.Unmarshal([]byte(data.Raw), &policies)
 	if err != nil {
-		return nil, fmt.Errorf("failed to unmarshal tag policies %w", err)
-	}
-
-	if len(policies.EvaluatePolicies.TagPolicies) > 0 {
-		checkedStr := "tag policy"
-		if len(policies.EvaluatePolicies.TagPolicies) > 1 {
-			checkedStr = "tag policies"
-		}
-		msg := fmt.Sprintf(`%d %s checked`, len(policies.EvaluatePolicies.TagPolicies), checkedStr)
-		if ctx.Config.IsLogging() {
-			logging.Logger.Info(msg)
-		} else {
-			_, err := fmt.Fprintf(ctx.ErrWriter, "%s\n", msg)
-			if err != nil {
-				return nil, fmt.Errorf("failed to write tag policies %w", err)
-			}
-		}
-	}
-
-	if len(policies.EvaluatePolicies.FinOpsPolicies) > 0 {
-		checkedStr := "finops policy"
-		if len(policies.EvaluatePolicies.FinOpsPolicies) > 1 {
-			checkedStr = "finops policies"
-		}
-		msg := fmt.Sprintf(`%d %s checked`, len(policies.EvaluatePolicies.FinOpsPolicies), checkedStr)
-		if ctx.Config.IsLogging() {
-			logging.Logger.Info(msg)
-		} else {
-			_, err := fmt.Fprintf(ctx.ErrWriter, "%s\n", msg)
-			if err != nil {
-				return nil, fmt.Errorf("failed to write fin ops policies %w", err)
-			}
-		}
+		return nil, fmt.Errorf("failed to unmarshal policies %w", err)
 	}
 
 	return &PolicyOutput{policies.EvaluatePolicies.TagPolicies, policies.EvaluatePolicies.FinOpsPolicies}, nil
@@ -324,7 +293,7 @@ func filterResource(rd *schema.ResourceData, al allowList) policy2Resource {
 	// make sure the keys in the values json are sorted so we get consistent policyShas
 	valuesJSON, err := jsonSorted.Marshal(filterValues(rd.RawValues, al))
 	if err != nil {
-		logging.Logger.WithError(err).WithField("address", rd.Address).Warn("Failed to marshal filtered values")
+		logging.Logger.Warn().Err(err).Str("address", rd.Address).Msg("Failed to marshal filtered values")
 	}
 
 	references := make([]policy2Reference, 0, len(rd.ReferencesMap))
@@ -394,7 +363,7 @@ func filterValues(rd gjson.Result, allowList map[string]gjson.Result) map[string
 					values[k] = filterValues(v, nestedAllow)
 				}
 			} else {
-				logging.Logger.WithField("Key", k).WithField("Type", allow.Type.String()).Warn("Unknown allow type")
+				logging.Logger.Warn().Str("Key", k).Str("Type", allow.Type.String()).Msg("Unknown allow type")
 			}
 		}
 	}
@@ -426,7 +395,7 @@ func (c *PolicyAPIClient) fetchAllowList() error {
 
 func (c *PolicyAPIClient) getPolicyResourceAllowList() (map[string]allowList, error) {
 	q := `
-		query {
+		query GetPolicyResourceAllowList{
 			policyResourceAllowList {
 				resourceType
                 allowed
