@@ -12,11 +12,12 @@ import (
 
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
-	"github.com/sirupsen/logrus"
+	"github.com/rs/zerolog"
 	"github.com/zclconf/go-cty/cty"
 	"github.com/zclconf/go-cty/cty/gocty"
 
 	"github.com/infracost/infracost/internal/hcl/funcs"
+	"github.com/infracost/infracost/internal/hcl/modules"
 )
 
 var (
@@ -144,6 +145,16 @@ func (blocks Blocks) OfType(t string) Blocks {
 	return results
 }
 
+func (blocks Blocks) FindLocalName(name string) *Block {
+	for _, block := range blocks {
+		if block.LocalName() == name {
+			return block
+		}
+	}
+
+	return nil
+}
+
 // BlockMatcher defines a struct that can be used to filter a list of blocks to a single Block.
 type BlockMatcher struct {
 	Type       string
@@ -235,8 +246,10 @@ func (blocks Blocks) Outputs(suppressNil bool) cty.Value {
 //
 // See Attribute for more info about how the values of Blocks are evaluated with their Context and returned.
 type Block struct {
-	// hclBlock is the underlying hcl.Block that has been parsed from a hcl.File
-	hclBlock *hcl.Block
+	// HCLBlock is the underlying hcl.Block that has been parsed from a hcl.File
+	HCLBlock *hcl.Block
+	// UniqueAttrs specifies infracost specific unique attributes that will be appended to the block values.
+	UniqueAttrs map[string]*hcl.Attribute
 	// context is a pointer to the contextual information that can be used when evaluating
 	// the Block and its Attributes.
 	context *Context
@@ -258,9 +271,10 @@ type Block struct {
 	parent *Block
 	// verbose determines whether the block uses verbose debug logging.
 	verbose    bool
-	logger     *logrus.Entry
+	logger     zerolog.Logger
 	newMock    func(attr *Attribute) cty.Value
 	attributes []*Attribute
+	reference  *Reference
 
 	Filename  string
 	StartLine int
@@ -271,7 +285,8 @@ type Block struct {
 type BlockBuilder struct {
 	MockFunc      func(a *Attribute) cty.Value
 	SetAttributes []SetAttributesFunc
-	Logger        *logrus.Entry
+	Logger        zerolog.Logger
+	HCLParser     *modules.SharedHCLParser
 }
 
 // NewBlock returns a Block with Context and child Blocks initialised.
@@ -287,7 +302,8 @@ func (b BlockBuilder) NewBlock(filename string, rootPath string, hclBlock *hcl.B
 			StartLine:   body.SrcRange.Start.Line,
 			EndLine:     body.SrcRange.End.Line,
 			context:     ctx,
-			hclBlock:    hclBlock,
+			UniqueAttrs: map[string]*hcl.Attribute{},
+			HCLBlock:    hclBlock,
 			moduleBlock: moduleBlock,
 			rootPath:    rootPath,
 			childBlocks: make(Blocks, len(body.Blocks)),
@@ -299,7 +315,7 @@ func (b BlockBuilder) NewBlock(filename string, rootPath string, hclBlock *hcl.B
 		block.setLogger(b.Logger)
 
 		for _, f := range b.SetAttributes {
-			f(block.FullName(), moduleBlock, hclBlock)
+			f(block)
 		}
 
 		for i, bb := range body.Blocks {
@@ -313,14 +329,15 @@ func (b BlockBuilder) NewBlock(filename string, rootPath string, hclBlock *hcl.B
 	// This might be because the *hcl.Block represents a whole file contents.
 	content, _, diag := hclBlock.Body.PartialContent(terraformSchemaV012)
 	if diag != nil && diag.HasErrors() {
-		b.Logger.Debugf("error loading partial content from hcl file %s", diag.Error())
+		b.Logger.Debug().Msgf("error loading partial content from hcl file %s", diag.Error())
 
 		block := &Block{
 			Filename:    filename,
 			StartLine:   hclBlock.DefRange.Start.Line,
 			EndLine:     hclBlock.DefRange.End.Line,
 			context:     ctx,
-			hclBlock:    hclBlock,
+			HCLBlock:    hclBlock,
+			UniqueAttrs: map[string]*hcl.Attribute{},
 			moduleBlock: moduleBlock,
 			rootPath:    rootPath,
 			verbose:     isLoggingVerbose,
@@ -336,7 +353,8 @@ func (b BlockBuilder) NewBlock(filename string, rootPath string, hclBlock *hcl.B
 		StartLine:   hclBlock.DefRange.Start.Line,
 		EndLine:     hclBlock.DefRange.End.Line,
 		context:     ctx,
-		hclBlock:    hclBlock,
+		HCLBlock:    hclBlock,
+		UniqueAttrs: map[string]*hcl.Attribute{},
 		moduleBlock: moduleBlock,
 		rootPath:    rootPath,
 		childBlocks: make(Blocks, len(content.Blocks)),
@@ -362,30 +380,30 @@ func (b BlockBuilder) CloneBlock(block *Block, index cty.Value) *Block {
 		childCtx = NewContext(&hcl.EvalContext{}, nil, b.Logger)
 	}
 
-	cloneHCL := *block.hclBlock
+	cloneHCL := *block.HCLBlock
 
 	clone := b.NewBlock(block.Filename, block.rootPath, &cloneHCL, childCtx, block.parent, block.moduleBlock)
-	if len(clone.hclBlock.Labels) > 0 {
-		position := len(clone.hclBlock.Labels) - 1
-		labels := make([]string, len(clone.hclBlock.Labels))
+	if len(clone.HCLBlock.Labels) > 0 {
+		position := len(clone.HCLBlock.Labels) - 1
+		labels := make([]string, len(clone.HCLBlock.Labels))
 		for i := 0; i < len(labels); i++ {
-			labels[i] = clone.hclBlock.Labels[i]
+			labels[i] = clone.HCLBlock.Labels[i]
 		}
 		if index.IsKnown() && !index.IsNull() {
 			switch index.Type() {
 			case cty.Number:
 				f, _ := index.AsBigFloat().Float64()
-				labels[position] = fmt.Sprintf("%s[%d]", clone.hclBlock.Labels[position], int(f))
+				labels[position] = fmt.Sprintf("%s[%d]", clone.HCLBlock.Labels[position], int(f))
 			case cty.String:
-				labels[position] = fmt.Sprintf("%s[%q]", clone.hclBlock.Labels[position], index.AsString())
+				labels[position] = fmt.Sprintf("%s[%q]", clone.HCLBlock.Labels[position], index.AsString())
 			default:
-				b.Logger.Debugf("Invalid key type in iterable: %#v", index.Type())
-				labels[position] = fmt.Sprintf("%s[%#v]", clone.hclBlock.Labels[position], index)
+				b.Logger.Debug().Msgf("Invalid key type in iterable: %#v", index.Type())
+				labels[position] = fmt.Sprintf("%s[%#v]", clone.HCLBlock.Labels[position], index)
 			}
 		} else {
-			labels[position] = fmt.Sprintf("%s[%d]", clone.hclBlock.Labels[position], block.cloneIndex)
+			labels[position] = fmt.Sprintf("%s[%d]", clone.HCLBlock.Labels[position], block.cloneIndex)
 		}
-		clone.hclBlock.Labels = labels
+		clone.SetLabels(labels)
 	}
 
 	indexVal, _ := gocty.ToCtyValue(index, cty.Number)
@@ -400,7 +418,7 @@ func (b BlockBuilder) CloneBlock(block *Block, index cty.Value) *Block {
 // BuildModuleBlocks loads all the Blocks for the module at the given path
 func (b BlockBuilder) BuildModuleBlocks(block *Block, modulePath string, rootPath string) (Blocks, error) {
 	var blocks Blocks
-	moduleFiles, err := loadDirectory(b.Logger, modulePath, true)
+	moduleFiles, err := loadDirectory(b.HCLParser, b.Logger, modulePath, true)
 	if err != nil {
 		return blocks, fmt.Errorf("failed to load module %s: %w", block.Label(), err)
 	}
@@ -413,7 +431,7 @@ func (b BlockBuilder) BuildModuleBlocks(block *Block, modulePath string, rootPat
 		}
 
 		if len(fileBlocks) > 0 {
-			b.Logger.Debugf("Added %d blocks from %s...", len(fileBlocks), fileBlocks[0].DefRange.Filename)
+			b.Logger.Debug().Msgf("Added %d blocks from %s...", len(fileBlocks), fileBlocks[0].DefRange.Filename)
 		}
 
 		for _, fileBlock := range fileBlocks {
@@ -427,40 +445,44 @@ func (b BlockBuilder) BuildModuleBlocks(block *Block, modulePath string, rootPat
 // SetAttributesFunc defines a function that sets required attributes on a hcl.Block.
 // This is done so that identifiers that are normally propagated from a Terraform state/apply
 // are set on the Block. This means they can be used properly in references and outputs.
-type SetAttributesFunc func(address string, moduleBlock *Block, block *hcl.Block)
+type SetAttributesFunc func(b *Block)
 
 // SetUUIDAttributes adds commonly used identifiers to the block so that it can be referenced by other
 // blocks in context evaluation. The identifiers are only set if they don't already exist as attributes
 // on the block.
-func SetUUIDAttributes(address string, moduleBlock *Block, block *hcl.Block) {
-	if body, ok := block.Body.(*hclsyntax.Body); ok {
-		if (block.Type == "resource" || block.Type == "data") && body.Attributes != nil {
-			h := sha256.New()
-			h.Write([]byte(address))
-			addressSha := hex.EncodeToString(h.Sum(nil))
+func SetUUIDAttributes(b *Block) {
+	t := b.Type()
+	if t != "resource" && t != "data" {
+		return
+	}
 
-			_, withCount := body.Attributes["count"]
-			_, withEach := body.Attributes["for_each"]
-			if _, ok := body.Attributes["id"]; !ok {
-				body.Attributes["id"] = newUniqueAttribute(addressSha, "id", withCount, withEach)
-			}
+	if body, ok := b.HCLBlock.Body.(*hclsyntax.Body); ok {
+		h := sha256.New()
+		h.Write([]byte(b.FullName()))
+		addressSha := hex.EncodeToString(h.Sum(nil))
 
-			if _, ok := body.Attributes["name"]; !ok {
-				body.Attributes["name"] = newUniqueAttribute(addressSha, "name", withCount, withEach)
-			}
+		_, withCount := body.Attributes["count"]
+		_, withEach := body.Attributes["for_each"]
 
-			if _, ok := body.Attributes["arn"]; !ok {
-				body.Attributes["arn"] = newArnAttribute(addressSha, "arn", withCount, withEach)
-			}
+		if _, ok := body.Attributes["id"]; !ok {
+			b.UniqueAttrs["id"] = newUniqueAttribute(addressSha, "id", withCount, withEach)
+		}
 
-			if _, ok := body.Attributes["self_link"]; !ok {
-				body.Attributes["self_link"] = newUniqueAttribute(addressSha, "self_link", withCount, withEach)
-			}
+		if _, ok := body.Attributes["name"]; !ok {
+			b.UniqueAttrs["name"] = newUniqueAttribute(addressSha, "name", withCount, withEach)
+		}
+
+		if _, ok := body.Attributes["arn"]; !ok {
+			b.UniqueAttrs["arn"] = newArnAttribute(addressSha, "arn", withCount, withEach)
+		}
+
+		if _, ok := body.Attributes["self_link"]; !ok {
+			b.UniqueAttrs["self_link"] = newUniqueAttribute(addressSha, "self_link", withCount, withEach)
 		}
 	}
 }
 
-func newUniqueAttribute(addressSha, name string, withCount bool, withEach bool) *hclsyntax.Attribute {
+func newUniqueAttribute(addressSha, name string, withCount bool, withEach bool) *hcl.Attribute {
 	// prefix ids with hcl- so they can be identified as fake
 	var exp hclsyntax.Expression = &hclsyntax.LiteralValueExpr{
 		Val: cty.StringVal("hcl-" + addressSha),
@@ -480,13 +502,13 @@ func newUniqueAttribute(addressSha, name string, withCount bool, withEach bool)
 		}
 	}
 
-	return &hclsyntax.Attribute{
+	return &hcl.Attribute{
 		Name: name,
 		Expr: exp,
 	}
 }
 
-func newArnAttribute(addressSha, name string, withCount bool, withEach bool) *hclsyntax.Attribute {
+func newArnAttribute(addressSha, name string, withCount bool, withEach bool) *hcl.Attribute {
 
 	// fakeARN replicates an aws arn string it deliberately leaves the
 	// region section (in between the 3rd and 4th semicolon) blank as
@@ -511,39 +533,12 @@ func newArnAttribute(addressSha, name string, withCount bool, withEach bool) *hc
 		}
 	}
 
-	return &hclsyntax.Attribute{
+	return &hcl.Attribute{
 		Name: name,
 		Expr: exp,
 	}
 }
 
-// InjectBlock takes a block and appends it to the Blocks childBlocks with the Block's
-// attributes set as contextual values on the child. In most cases this is because we've expanded
-// the block into further Blocks as part of a count or for_each.
-func (b *Block) InjectBlock(block *Block, name string) {
-	block.hclBlock.Labels = []string{}
-	block.hclBlock.Type = name
-
-	for attrName, attr := range block.AttributesAsMap() {
-		b.context.Root().SetByDot(attr.Value(), fmt.Sprintf("%s.%s.%s", b.Reference().String(), name, attrName))
-	}
-
-	b.childBlocks = append(b.childBlocks, block)
-}
-
-// RemoveDynamicBlocks removes all the child Blocks of type name that have a parent of type "dynamic".
-func (b *Block) RemoveDynamicBlocks(name string) {
-	var filtered Blocks
-
-	for _, block := range b.childBlocks {
-		if block.Type() != name || block.parent.Type() != "dynamic" {
-			filtered = append(filtered, block)
-		}
-	}
-
-	b.childBlocks = filtered
-}
-
 // IsCountExpanded returns if the Block has been expanded as part of a for_each or count evaluation.
 func (b *Block) IsCountExpanded() bool {
 	return b.expanded
@@ -633,14 +628,12 @@ type ModuleMetadata struct {
 	EndLine   int    `json:"endLine,omitempty"`
 }
 
-func (b *Block) setLogger(logger *logrus.Entry) {
+func (b *Block) setLogger(logger zerolog.Logger) {
 	// Use the provided logger as is initially so we avoid a nil pointer in the case where we need to log
 	// an error while calculating b.FullName().
 	b.logger = logger
 
-	blockLogger := logger.WithFields(logrus.Fields{
-		"block_name": b.FullName(),
-	})
+	blockLogger := logger.With().Str("block_name", b.FullName()).Logger()
 
 	b.logger = blockLogger
 }
@@ -766,7 +759,7 @@ func (b *Block) GetChildBlock(name string) *Block {
 //
 // Then "credit_specification" &  "ebs_block_device" would be valid names that could be used to retrieve child Blocks.
 func (b *Block) GetChildBlocks(name string) []*Block {
-	if b == nil || b.hclBlock == nil {
+	if b == nil || b.HCLBlock == nil {
 		return nil
 	}
 
@@ -786,7 +779,7 @@ func (b *Block) HasChild(childElement string) bool {
 
 // Children returns all the child Blocks associated with this Block.
 func (b *Block) Children() Blocks {
-	if b == nil || b.hclBlock == nil {
+	if b == nil || b.HCLBlock == nil {
 		return nil
 	}
 
@@ -807,7 +800,7 @@ func (b *Block) Children() Blocks {
 //
 // ami & instance_type are the Attributes of this Block and credit_specification is a child Block.
 func (b *Block) GetAttributes() []*Attribute {
-	if b == nil || b.hclBlock == nil {
+	if b == nil || b.HCLBlock == nil {
 		return nil
 	}
 
@@ -818,22 +811,38 @@ func (b *Block) GetAttributes() []*Attribute {
 	hclAttributes := b.getHCLAttributes()
 
 	// Sort the attributes so the order is deterministic
-	keys := make([]string, 0, len(hclAttributes))
+	keys := make([]string, 0, len(hclAttributes)+len(b.UniqueAttrs))
 	for k := range hclAttributes {
 		keys = append(keys, k)
 	}
+	for k := range b.UniqueAttrs {
+		keys = append(keys, k)
+	}
 	sort.Strings(keys)
 
 	var attributes = make([]*Attribute, 0, len(keys))
 	for _, k := range keys {
+		if v, ok := b.UniqueAttrs[k]; ok {
+			attributes = append(attributes, &Attribute{
+				newMock: b.newMock,
+				HCLAttr: v,
+				Ctx:     b.context,
+				Verbose: b.verbose,
+				Logger: b.logger.With().Str(
+					"attribute_name", k,
+				).Logger(),
+			})
+			continue
+		}
+
 		attributes = append(attributes, &Attribute{
 			newMock: b.newMock,
 			HCLAttr: hclAttributes[k],
 			Ctx:     b.context,
 			Verbose: b.verbose,
-			Logger: b.logger.WithFields(logrus.Fields{
-				"attribute_name": hclAttributes[k].Name,
-			}),
+			Logger: b.logger.With().Str(
+				"attribute_name", hclAttributes[k].Name,
+			).Logger(),
 		})
 	}
 
@@ -850,7 +859,7 @@ func (b *Block) loadFileContentsToAttributes(attributes []*Attribute) []*Attribu
 		if attribute.Name() == "filename" {
 			content, err := funcs.File(b.rootPath, attribute.Value())
 			if err != nil {
-				b.logger.WithError(err).Debugf("failed to load %s file contents", b.FullName())
+				b.logger.Debug().Err(err).Msgf("failed to load %s file contents", b.FullName())
 				break
 			}
 
@@ -888,9 +897,9 @@ func (b *Block) syntheticAttribute(name string, val cty.Value) *Attribute {
 		HCLAttr: hclAttr,
 		Ctx:     b.context,
 		Verbose: b.verbose,
-		Logger: b.logger.WithFields(logrus.Fields{
-			"attribute_name": name,
-		}),
+		Logger: b.logger.With().Str(
+			"attribute_name", name,
+		).Logger(),
 	}
 }
 
@@ -909,7 +918,7 @@ func (b *Block) syntheticAttribute(name string, val cty.Value) *Attribute {
 // ami & instance_type are both valid Attribute names that can be used to lookup Block Attributes.
 func (b *Block) GetAttribute(name string) *Attribute {
 	var attr *Attribute
-	if b == nil || b.hclBlock == nil {
+	if b == nil || b.HCLBlock == nil {
 		return attr
 	}
 
@@ -935,15 +944,17 @@ func (b *Block) AttributesAsMap() map[string]*Attribute {
 }
 
 func (b *Block) getHCLAttributes() hcl.Attributes {
-	switch body := b.hclBlock.Body.(type) {
+	switch body := b.HCLBlock.Body.(type) {
 	case *hclsyntax.Body:
 		attributes := make(hcl.Attributes)
 		for _, a := range body.Attributes {
-			attributes[a.Name] = a.AsHCLAttribute()
+			if _, ok := b.UniqueAttrs[a.Name]; !ok {
+				attributes[a.Name] = a.AsHCLAttribute()
+			}
 		}
 		return attributes
 	default:
-		_, body, diag := b.hclBlock.Body.PartialContent(terraformSchemaV012)
+		_, body, diag := b.HCLBlock.Body.PartialContent(terraformSchemaV012)
 		if diag != nil {
 			return nil
 		}
@@ -951,6 +962,12 @@ func (b *Block) getHCLAttributes() hcl.Attributes {
 		if diag != nil {
 			return nil
 		}
+		for k, a := range attrs {
+			if _, ok := b.UniqueAttrs[a.Name]; !ok {
+				delete(attrs, k)
+			}
+		}
+
 		return attrs
 	}
 }
@@ -1012,6 +1029,10 @@ func (b *Block) values() cty.Value {
 // Reference returns a Reference to the given Block this can be used to when printing
 // out full names of Blocks to stdout or a file.
 func (b *Block) Reference() *Reference {
+	if b.reference != nil && b.reference.String() != "" {
+		return b.reference
+	}
+
 	var parts []string
 
 	if b.Type() != "resource" || b.parent != nil {
@@ -1021,13 +1042,49 @@ func (b *Block) Reference() *Reference {
 	parts = append(parts, b.Labels()...)
 	ref, err := newReference(parts)
 	if err != nil {
-		b.logger.WithError(err).Debugf(
+		b.logger.Debug().Err(err).Msgf(
 			"returning empty block reference because we encountered an error generating a new reference",
 		)
-		return &Reference{}
+		ref = &Reference{}
 	}
 
-	return ref
+	b.reference = ref
+
+	return b.reference
+}
+
+// VerticesReferenced traverses the block attributes and child blocks to build a complete
+// list of all the vertices referenced by the Block. We build a special VertexReference
+// if the block uses a provider but doesn't have one referenced. This is because blocks
+// will depend on the default provider to get the correct region data, even if not explicitly
+// referenced as a reference.
+func (b *Block) VerticesReferenced() []VertexReference {
+	var refs []VertexReference
+
+	hasProviderAttr := false
+
+	for _, attr := range b.GetAttributes() {
+		if attr.Name() == "provider" {
+			hasProviderAttr = true
+		}
+
+		refs = append(refs, attr.VerticesReferenced(b)...)
+	}
+
+	for _, childBlock := range b.Children() {
+		refs = append(refs, childBlock.VerticesReferenced()...)
+	}
+
+	if !hasProviderAttr && usesProviderConfiguration(b) {
+		providerName := b.Provider()
+		if providerName != "" {
+			refs = append(refs, VertexReference{
+				Key: fmt.Sprintf("provider.%s", providerName),
+			})
+		}
+	}
+
+	return refs
 }
 
 // LocalName is the name relative to the current module
@@ -1064,11 +1121,21 @@ func (b *Block) FullName() string {
 }
 
 func (b *Block) Type() string {
-	return b.hclBlock.Type
+	return b.HCLBlock.Type
+}
+
+func (b *Block) SetType(t string) {
+	b.reference = nil
+	b.HCLBlock.Type = t
 }
 
 func (b *Block) Labels() []string {
-	return b.hclBlock.Labels
+	return b.HCLBlock.Labels
+}
+
+func (b *Block) SetLabels(labels []string) {
+	b.reference = nil
+	b.HCLBlock.Labels = labels
 }
 
 func (b *Block) Context() *Context {
@@ -1089,6 +1156,27 @@ func (b *Block) NameLabel() string {
 	return ""
 }
 
+// HasDynamicBlock searches all the nested children of the given block to see if
+// any are type "dynamic". This is used before embarking on dynamic expansion
+// logic.
+func (b *Block) HasDynamicBlock() bool {
+	if b == nil {
+		return false
+	}
+
+	for _, child := range b.Children() {
+		if child.Type() == "dynamic" {
+			return true
+		}
+
+		if child.HasDynamicBlock() {
+			return true
+		}
+	}
+
+	return false
+}
+
 var (
 	countRegex   = regexp.MustCompile(`\[(\d+)\]$`)
 	foreachRegex = regexp.MustCompile(`\["(.*)"\]$`)
@@ -1121,7 +1209,7 @@ func (b *Block) Key() *string {
 }
 
 func (b *Block) Label() string {
-	return strings.Join(b.hclBlock.Labels, ".")
+	return strings.Join(b.HCLBlock.Labels, ".")
 }
 
 func loadBlocksFromFile(file file, schema *hcl.BodySchema) (hcl.Blocks, error) {
@@ -1208,7 +1296,7 @@ func randomShuffleValues(b *Block) cty.Value {
 	var x = 1
 	err := gocty.FromCtyValue(count, &x)
 	if err != nil {
-		b.logger.WithError(err).Debugf("couldn't load result_count to int for random_shuffle")
+		b.logger.Debug().Err(err).Msgf("couldn't load result_count to int for random_shuffle")
 	}
 
 	if x > len(elements)-1 {
@@ -1240,7 +1328,7 @@ func googleComputeZonesValues(b *Block) cty.Value {
 		if err == nil {
 			region = str
 		} else {
-			b.logger.WithError(err).Debugf("could not parse gcp compute zone region")
+			b.logger.Debug().Err(err).Msgf("could not parse gcp compute zone region")
 		}
 	}
 
@@ -1296,3 +1384,7 @@ func getFromProvider(b *Block, provider, key string) cty.Value {
 
 	return val
 }
+
+func usesProviderConfiguration(b *Block) bool {
+	return b.Type() == "resource" || b.Type() == "data"
+}
