@@ -11,9 +11,10 @@ import (
 	"strings"
 
 	"github.com/hashicorp/hcl/v2"
-	"github.com/hashicorp/hcl/v2/hclparse"
-	"github.com/sirupsen/logrus"
+	"github.com/rs/zerolog"
+	"github.com/rs/zerolog/log"
 	"github.com/zclconf/go-cty/cty"
+	"github.com/zclconf/go-cty/cty/gocty"
 
 	"github.com/infracost/infracost/internal/clierror"
 	"github.com/infracost/infracost/internal/config"
@@ -123,7 +124,7 @@ func OptionWithRawCtyInput(input cty.Value) (op Option) {
 	defer func() {
 		err := recover()
 		if err != nil {
-			logging.Logger.Debugf("recovering from panic using raw input Terraform var %s", err)
+			logging.Logger.Debug().Msgf("recovering from panic using raw input Terraform var %s", err)
 			op = func(p *Parser) {}
 		}
 	}()
@@ -175,9 +176,7 @@ func OptionWithTerraformWorkspace(name string) Option {
 	name = strings.TrimSpace(name)
 	return func(p *Parser) {
 		if name != "" {
-			if p.logger != nil {
-				p.logger.Debugf("setting HCL parser to use user provided Terraform workspace: '%s'", name)
-			}
+			p.logger.Debug().Msgf("setting HCL parser to use user provided Terraform workspace: '%s'", name)
 
 			p.workspaceName = name
 		}
@@ -206,10 +205,11 @@ type Parser struct {
 	inputVars             map[string]cty.Value
 	workspaceName         string
 	moduleLoader          *modules.ModuleLoader
+	hclParser             *modules.SharedHCLParser
 	blockBuilder          BlockBuilder
 	newSpinner            ui.SpinnerFunc
 	remoteVariablesLoader *RemoteVariablesLoader
-	logger                *logrus.Entry
+	logger                zerolog.Logger
 	hasChanges            bool
 	moduleSuffix          string
 }
@@ -217,7 +217,7 @@ type Parser struct {
 // LoadParsers inits a list of Parser with the provided option and initialPath. LoadParsers locates Terraform files
 // in the given initialPath and returns a Parser for each directory it locates a Terraform project within. If
 // the initialPath contains Terraform files at the top level parsers will be len 1.
-func LoadParsers(ctx *config.ProjectContext, initialPath string, loader *modules.ModuleLoader, locatorConfig *ProjectLocatorConfig, logger *logrus.Entry, options ...Option) ([]*Parser, error) {
+func LoadParsers(ctx *config.ProjectContext, initialPath string, loader *modules.ModuleLoader, locatorConfig *ProjectLocatorConfig, logger zerolog.Logger, options ...Option) ([]*Parser, error) {
 	pl := NewProjectLocator(logger, locatorConfig)
 	rootPaths := pl.FindRootModules(initialPath)
 	if len(rootPaths) == 0 && len(locatorConfig.ChangedObjects) > 0 {
@@ -275,16 +275,19 @@ func LoadParsers(ctx *config.ProjectContext, initialPath string, loader *modules
 	return parsers, nil
 }
 
-func newParser(projectRoot RootPath, moduleLoader *modules.ModuleLoader, logger *logrus.Entry, options ...Option) *Parser {
-	parserLogger := logger.WithFields(logrus.Fields{
-		"parser_path": projectRoot.Path,
-	})
+func newParser(projectRoot RootPath, moduleLoader *modules.ModuleLoader, logger zerolog.Logger, options ...Option) *Parser {
+	parserLogger := logger.With().Str(
+		"parser_path", projectRoot.Path,
+	).Logger()
+
+	hclParser := modules.NewSharedHCLParser()
 
 	p := &Parser{
 		initialPath:   projectRoot.Path,
 		hasChanges:    projectRoot.HasChanges,
 		workspaceName: defaultTerraformWorkspaceName,
-		blockBuilder:  BlockBuilder{SetAttributes: []SetAttributesFunc{SetUUIDAttributes}, Logger: logger},
+		hclParser:     hclParser,
+		blockBuilder:  BlockBuilder{SetAttributes: []SetAttributesFunc{SetUUIDAttributes}, Logger: logger, HCLParser: hclParser},
 		logger:        parserLogger,
 		moduleLoader:  moduleLoader,
 	}
@@ -293,12 +296,12 @@ func newParser(projectRoot RootPath, moduleLoader *modules.ModuleLoader, logger
 
 	defaultTfFile := path.Join(projectRoot.Path, "terraform.tfvars")
 	if _, err := os.Stat(defaultTfFile); err == nil {
-		parserLogger.Debugf("using terraform.tfvar file %s", defaultTfFile)
+		parserLogger.Debug().Msgf("using terraform.tfvar file %s", defaultTfFile)
 		defaultVarFiles = append(defaultVarFiles, defaultTfFile)
 	}
 
 	if _, err := os.Stat(defaultTfFile + ".json"); err == nil {
-		parserLogger.Debugf("using terraform.tfvar file %s.json", defaultTfFile)
+		parserLogger.Debug().Msgf("using terraform.tfvar file %s.json", defaultTfFile)
 		defaultVarFiles = append(defaultVarFiles, defaultTfFile+".json")
 	}
 
@@ -307,7 +310,7 @@ func newParser(projectRoot RootPath, moduleLoader *modules.ModuleLoader, logger
 	for _, info := range infos {
 		name := info.Name()
 		if strings.HasSuffix(name, autoVarsSuffix) || strings.HasSuffix(name, autoVarsSuffix+".json") {
-			parserLogger.Debugf("using auto var file %s", name)
+			parserLogger.Debug().Msgf("using auto var file %s", name)
 			defaultVarFiles = append(defaultVarFiles, path.Join(projectRoot.Path, name))
 		}
 	}
@@ -321,6 +324,65 @@ func newParser(projectRoot RootPath, moduleLoader *modules.ModuleLoader, logger
 	return p
 }
 
+// YAML returns a yaml representation of Parser, that can be used to "explain" the auto-detection functionality.
+func (p *Parser) YAML() string {
+	str := strings.Builder{}
+	str.WriteString(fmt.Sprintf("  - path: %s\n    name: %s-%s\n", p.initialPath, strings.ReplaceAll(p.initialPath, "/", "-"), p.moduleSuffix))
+	if len(p.tfvarsPaths) > 0 || len(p.defaultVarFiles) > 0 {
+		str.WriteString("    terraform_var_files:\n")
+		written := map[string]bool{}
+
+		for _, varFile := range p.defaultVarFiles {
+			p, err := filepath.Rel(p.initialPath, varFile)
+			if err != nil {
+				continue
+			}
+
+			str.WriteString(fmt.Sprintf("      - %s\n", p))
+			written[varFile] = true
+		}
+
+		for _, varFile := range p.tfvarsPaths {
+			p, err := filepath.Rel(p.initialPath, varFile)
+			if err != nil {
+				continue
+			}
+
+			if written[varFile] {
+				continue
+			}
+
+			str.WriteString(fmt.Sprintf("      - %s\n", p))
+			written[varFile] = true
+		}
+	}
+
+	str.WriteString(fmt.Sprintf("    terraform_workspace: %s\n", p.workspaceName))
+
+	if len(p.tfEnvVars) > 0 {
+		str.WriteString("  terraform_vars:\n")
+
+		keys := make([]string, len(p.tfEnvVars), 0)
+		for key := range p.tfEnvVars {
+			keys = append(keys, key)
+		}
+
+		sort.Strings(keys)
+
+		for _, key := range keys {
+			var value string
+			err := gocty.FromCtyValue(p.tfEnvVars[key], &value)
+			if err != nil {
+				continue
+			}
+
+			str.WriteString(fmt.Sprintf("      %s:%s\n", key, value))
+		}
+	}
+
+	return str.String()
+}
+
 // ParseDirectory parses all the terraform files in the initialPath into Blocks and then passes them to an Evaluator
 // to fill these Blocks with additional Context information. Parser does not parse any blocks outside the root Module.
 // It instead leaves ModuleLoader to fetch these Modules on demand. See ModuleLoader.Load for more information.
@@ -339,11 +401,11 @@ func (p *Parser) ParseDirectory() (m *Module, err error) {
 		}
 	}()
 
-	p.logger.Debugf("Beginning parse for directory '%s'...", p.initialPath)
+	p.logger.Debug().Msgf("Beginning parse for directory '%s'...", p.initialPath)
 
 	// load the initial root directory into a list of hcl files
 	// at this point these files have no schema associated with them.
-	files, err := loadDirectory(p.logger, p.initialPath, false)
+	files, err := loadDirectory(p.hclParser, p.logger, p.initialPath, false)
 	if err != nil {
 		return m, err
 	}
@@ -358,7 +420,7 @@ func (p *Parser) ParseDirectory() (m *Module, err error) {
 		return m, errors.New("No valid terraform files found given path, try a different directory")
 	}
 
-	p.logger.Debug("Loading TFVars...")
+	p.logger.Debug().Msg("Loading TFVars...")
 	inputVars, err := p.loadVars(blocks, p.tfvarsPaths)
 	if err != nil {
 		return m, err
@@ -370,7 +432,7 @@ func (p *Parser) ParseDirectory() (m *Module, err error) {
 		return m, fmt.Errorf("Error loading Terraform modules: %w", err)
 	}
 
-	p.logger.Debug("Evaluating expressions...")
+	p.logger.Debug().Msg("Evaluating expressions...")
 	workingDir, err := os.Getwd()
 	if err != nil {
 		return m, fmt.Errorf("Error could not evaluate current working directory %w", err)
@@ -397,9 +459,28 @@ func (p *Parser) ParseDirectory() (m *Module, err error) {
 		nil,
 	)
 
-	root, err := evaluator.Run()
-	if err != nil {
-		return m, err
+	var root *Module
+
+	// Graph evaluation
+	if evaluator.isGraphEvaluator() {
+		// we use the base zerolog log here so that it's consistent with the spinner logs
+		log.Info().Msgf("Building project with experimental graph runner")
+
+		g, err := NewGraphWithRoot(p.logger, nil)
+		if err != nil {
+			return m, err
+		}
+
+		root, err = g.Run(evaluator)
+		if err != nil {
+			return m, err
+		}
+	} else {
+		// Existing evaluation
+		root, err = evaluator.Run()
+		if err != nil {
+			return m, err
+		}
 	}
 
 	root.HasChanges = p.hasChanges
@@ -419,12 +500,12 @@ func (p *Parser) parseDirectoryFiles(files []file) (Blocks, error) {
 	for _, file := range files {
 		fileBlocks, err := loadBlocksFromFile(file, nil)
 		if err != nil {
-			p.logger.Debugf("skipping file could not load blocks err: %s", err)
+			p.logger.Debug().Msgf("skipping file could not load blocks err: %s", err)
 			continue
 		}
 
 		if len(fileBlocks) > 0 {
-			p.logger.Debugf("Added %d blocks from %s...", len(fileBlocks), fileBlocks[0].DefRange.Filename)
+			p.logger.Debug().Msgf("Added %d blocks from %s...", len(fileBlocks), fileBlocks[0].DefRange.Filename)
 		}
 
 		for _, fileBlock := range fileBlocks {
@@ -448,7 +529,7 @@ func (p *Parser) loadVars(blocks Blocks, filenames []string) (map[string]cty.Val
 		remoteVars, err := p.remoteVariablesLoader.Load(blocks)
 
 		if err != nil {
-			p.logger.Warnf("could not load vars from Terraform Cloud: %s", err)
+			p.logger.Warn().Msgf("could not load vars from Terraform Cloud: %s", err)
 			return combinedVars, err
 		}
 
@@ -460,7 +541,7 @@ func (p *Parser) loadVars(blocks Blocks, filenames []string) (map[string]cty.Val
 	for _, name := range p.defaultVarFiles {
 		err := p.loadAndCombineVars(name, combinedVars)
 		if err != nil {
-			p.logger.WithError(err).Warnf("could not load vars from auto var file %s", name)
+			p.logger.Warn().Err(err).Msgf("could not load vars from auto var file %s", name)
 			continue
 		}
 	}
@@ -510,11 +591,9 @@ func (p *Parser) loadVarFile(filename string) (map[string]cty.Value, error) {
 
 	var parseFunc func(filename string) (*hcl.File, hcl.Diagnostics)
 
-	hclParser := hclparse.NewParser()
-
-	parseFunc = hclParser.ParseHCLFile
+	parseFunc = p.hclParser.ParseHCLFile
 	if strings.HasSuffix(filename, ".json") {
-		parseFunc = hclParser.ParseJSONFile
+		parseFunc = p.hclParser.ParseJSONFile
 	}
 
 	variableFile, diags := parseFunc(filename)
@@ -523,9 +602,9 @@ func (p *Parser) loadVarFile(filename string) (map[string]cty.Value, error) {
 		// We can safely ignore these Attribute errors and continue to get the raw attributes.
 		// The first value for the variable will be used.
 		if areDiagnosticsAttributeErrors(diags) {
-			p.logger.WithError(errors.New(diags.Error())).Debugf("duplicate variables detected parsing file %s, using the first values defined", filename)
+			p.logger.Debug().Err(errors.New(diags.Error())).Msgf("duplicate variables detected parsing file %s, using the first values defined", filename)
 		} else {
-			p.logger.WithError(errors.New(diags.Error())).Debugf("could not parse supplied var file %s", filename)
+			p.logger.Debug().Err(errors.New(diags.Error())).Msgf("could not parse supplied var file %s", filename)
 
 			return inputVars, nil
 		}
@@ -533,18 +612,15 @@ func (p *Parser) loadVarFile(filename string) (map[string]cty.Value, error) {
 
 	attrs, _ := variableFile.Body.JustAttributes()
 
-	fields := make(logrus.Fields, len(attrs))
 	for _, attr := range attrs {
 		value, diag := attr.Expr.Value(&hcl.EvalContext{})
 		if diag.HasErrors() {
-			p.logger.WithError(errors.New(diag.Error())).Debugf("problem evaluating input var %s", attr.Name)
+			p.logger.Debug().Err(errors.New(diag.Error())).Msgf("problem evaluating input var %s", attr.Name)
 		}
 
 		inputVars[attr.Name] = value
-		fields[attr.Name] = value
 	}
 
-	p.logger.WithFields(fields).Debugf("adding input vars from file %s", filename)
 	return inputVars, nil
 }
 
@@ -563,14 +639,14 @@ type file struct {
 	hclFile *hcl.File
 }
 
-func loadDirectory(logger *logrus.Entry, fullPath string, stopOnHCLError bool) ([]file, error) {
-	hclParser := hclparse.NewParser()
-
+func loadDirectory(hclParser *modules.SharedHCLParser, logger zerolog.Logger, fullPath string, stopOnHCLError bool) ([]file, error) {
 	fileInfos, err := os.ReadDir(fullPath)
 	if err != nil {
 		return nil, err
 	}
 
+	files := make([]file, 0)
+
 	for _, info := range fileInfos {
 		if info.IsDir() {
 			continue
@@ -591,20 +667,17 @@ func loadDirectory(logger *logrus.Entry, fullPath string, stopOnHCLError bool) (
 		}
 
 		path := filepath.Join(fullPath, info.Name())
-		_, diag := parseFunc(path)
+		f, diag := parseFunc(path)
 		if diag != nil && diag.HasErrors() {
 			if stopOnHCLError {
 				return nil, diag
 			}
 
-			logger.Debugf("skipping file: %s hcl parsing err: %s", path, diag.Error())
+			logger.Debug().Msgf("skipping file: %s hcl parsing err: %s", path, diag.Error())
 			continue
 		}
-	}
 
-	files := make([]file, 0, len(hclParser.Files()))
-	for filename, f := range hclParser.Files() {
-		files = append(files, file{hclFile: f, path: filename})
+		files = append(files, file{hclFile: f, path: path})
 	}
 
 	// sort files by path to ensure consistent ordering
