@@ -119,5 +119,5 @@ func TestAutoscalingGroup_spot(t *testing.T) {
 		},
 	}
 
-	tftest.ResourceTests(t, tf, schema.NewEmptyUsageMap(), resourceChecks)
+	tftest.ResourceTests(t, tf, schema.UsageMap{}, resourceChecks)
 }
