@@ -137,6 +137,7 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getApplicationInsightsStandardWebTestRegistryItem(),
 	getRecoveryServicesVaultRegistryItem(),
 	getBackupProtectedVmRegistryItem(),
+	getStorageManagementPolicyRegistryItem(),
 	getStorageQueueRegistryItem(),
 	getStorageShareRegistryItem(),
 	getLogicAppIntegrationAccountRegistryItem(),
@@ -559,7 +560,6 @@ var FreeResources = []string{
 	"azurerm_storage_blob_inventory_policy",
 	"azurerm_storage_container",
 	"azurerm_storage_data_lake_gen2_path",
-	"azurerm_storage_management_policy",
 	"azurerm_storage_object_replication",
 	"azurerm_storage_share_directory",
 	"azurerm_storage_share_file",
