@@ -4,7 +4,6 @@ import (
 	"testing"
 
 	"github.com/shopspring/decimal"
-	log "github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/assert"
 	"github.com/tidwall/gjson"
 
@@ -412,9 +411,9 @@ func TestParseJSONResources(t *testing.T) {
 	conf := parsed.Get("configuration.root_module")
 	vars := parsed.Get("variables")
 
-	p := NewParser(config.NewProjectContext(config.EmptyRunContext(), &config.Project{}, log.Fields{}), true)
+	p := NewParser(config.NewProjectContext(config.EmptyRunContext(), &config.Project{}, map[string]interface{}{}), true)
 
-	partials := p.parseJSONResources(false, nil, usage, parsed, providerConf, conf, vars)
+	partials := p.parseJSONResources(false, nil, usage, NewConfLoader(conf), parsed, providerConf, vars)
 	actual := make([]*schema.Resource, len(partials))
 	for i, partial := range partials {
 		actual[i] = schema.BuildResource(partial, nil)
@@ -484,7 +483,7 @@ func TestCreateResource(t *testing.T) {
 		},
 	}
 
-	p := NewParser(config.NewProjectContext(config.EmptyRunContext(), &config.Project{}, log.Fields{}), true)
+	p := NewParser(config.NewProjectContext(config.EmptyRunContext(), &config.Project{}, map[string]interface{}{}), true)
 
 	for _, test := range tests {
 		partial := p.createPartialResource(test.data, nil)
@@ -664,8 +663,8 @@ func TestParseResourceData(t *testing.T) {
 		"module.module1.aws_nat_gateway.nat2": "eu-west-2",
 	}
 
-	p := NewParser(config.NewProjectContext(config.EmptyRunContext(), &config.Project{}, log.Fields{}), true)
-	actual := p.parseResourceData(false, providerConf, planVals, conf, vars)
+	p := NewParser(config.NewProjectContext(config.EmptyRunContext(), &config.Project{}, map[string]interface{}{}), true)
+	actual := p.parseResourceData(false, NewConfLoader(conf), providerConf, planVals, vars)
 
 	for k, v := range actual {
 		assert.Equal(t, expected[k].Address, v.Address)
@@ -733,8 +732,8 @@ func TestParseReferences_plan(t *testing.T) {
 		}`,
 	}
 
-	p := NewParser(config.NewProjectContext(config.EmptyRunContext(), &config.Project{}, log.Fields{}), true)
-	p.parseReferences(resData, conf)
+	p := NewParser(config.NewProjectContext(config.EmptyRunContext(), &config.Project{}, map[string]interface{}{}), true)
+	p.parseReferences(resData, NewConfLoader(conf))
 
 	assert.Equal(t, []*schema.ResourceData{vol1}, resData["aws_ebs_snapshot.snapshot1"].References("volume_id"))
 }
@@ -773,8 +772,8 @@ func TestParseReferences_state(t *testing.T) {
 
 	conf := gjson.Result{}
 
-	p := NewParser(config.NewProjectContext(config.EmptyRunContext(), &config.Project{}, log.Fields{}), true)
-	p.parseReferences(resData, conf)
+	p := NewParser(config.NewProjectContext(config.EmptyRunContext(), &config.Project{}, map[string]interface{}{}), true)
+	p.parseReferences(resData, NewConfLoader(conf))
 
 	assert.Equal(t, []*schema.ResourceData{vol1}, resData["aws_ebs_snapshot.snapshot1"].References("volume_id"))
 }
@@ -946,7 +945,7 @@ func TestParseKnownModuleRefs(t *testing.T) {
 	}
 	assert.Nil(t, resData[res.Address].References("launch_template"))
 
-	parseKnownModuleRefs(resData, conf)
+	parseKnownModuleRefs(resData, NewConfLoader(conf))
 
 	assert.NotNil(t, resData[res.Address].References("launch_template"))
 }
