@@ -121,7 +121,7 @@ func (r *MySQLFlexibleServer) storageCostComponent() *schema.CostComponent {
 			Service:       strPtr("Azure Database for MySQL"),
 			ProductFamily: strPtr("Databases"),
 			AttributeFilters: []*schema.AttributeFilter{
-				{Key: "productName", Value: strPtr("Az Database for MySQL Flexible Server Storage")},
+				{Key: "productName", Value: strPtr("Az DB for MySQL Flexible Server Storage")},
 				{Key: "meterName", Value: strPtr("Storage Data Stored")},
 			},
 		},
@@ -157,7 +157,7 @@ func (r *MySQLFlexibleServer) iopsCostComponent() *schema.CostComponent {
 			Service:       strPtr("Azure Database for MySQL"),
 			ProductFamily: strPtr("Databases"),
 			AttributeFilters: []*schema.AttributeFilter{
-				{Key: "productName", Value: strPtr("Az Database for MySQL Flexible Server Storage")},
+				{Key: "productName", Value: strPtr("Az DB for MySQL Flexible Server Storage")},
 				{Key: "skuName", Value: strPtr("Additional IOPS")},
 			},
 		},
