@@ -4,8 +4,8 @@ import (
 	"fmt"
 	"strings"
 
+	"github.com/rs/zerolog/log"
 	"github.com/shopspring/decimal"
-	log "github.com/sirupsen/logrus"
 
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
@@ -267,7 +267,7 @@ func (r *SQLDatabase) provisionedComputeCostComponents() []*schema.CostComponent
 	productNameRegex := fmt.Sprintf("/%s - %s/", r.Tier, r.Family)
 	name := fmt.Sprintf("Compute (provisioned, %s)", r.SKU)
 
-	log.Warnf("'Multiple products found' are safe to ignore for '%s' due to limitations in the Azure API.", name)
+	log.Warn().Msgf("'Multiple products found' are safe to ignore for '%s' due to limitations in the Azure API.", name)
 
 	costComponents := []*schema.CostComponent{
 		{
@@ -330,7 +330,7 @@ func (r *SQLDatabase) longTermRetentionCostComponent() *schema.CostComponent {
 
 	redundancyType, ok := mssqlStorageRedundancyTypeMapping[strings.ToLower(r.BackupStorageType)]
 	if !ok {
-		log.Warnf("Unrecognized backup storage type '%s'", r.BackupStorageType)
+		log.Warn().Msgf("Unrecognized backup storage type '%s'", r.BackupStorageType)
 		redundancyType = "RA-GRS"
 	}
 
@@ -356,7 +356,7 @@ func (r *SQLDatabase) pitrBackupCostComponent() *schema.CostComponent {
 
 	redundancyType, ok := mssqlStorageRedundancyTypeMapping[strings.ToLower(r.BackupStorageType)]
 	if !ok {
-		log.Warnf("Unrecognized backup storage type '%s'", r.BackupStorageType)
+		log.Warn().Msgf("Unrecognized backup storage type '%s'", r.BackupStorageType)
 		redundancyType = "RA-GRS"
 	}
 
@@ -381,7 +381,7 @@ func (r *SQLDatabase) extraDataStorageCostComponent(extraStorageGB float64) *sch
 		tier, ok = mssqlTierMapping[strings.ToLower(r.SKU)[:1]]
 
 		if !ok {
-			log.Warnf("Unrecognized tier for SKU '%s' for resource %s", r.SKU, r.Address)
+			log.Warn().Msgf("Unrecognized tier for SKU '%s' for resource %s", r.SKU, r.Address)
 			return nil
 		}
 	}
