@@ -35,7 +35,7 @@ func (r *ComputeInstanceGroupManager) PopulateUsage(u *schema.UsageData) {
 func (r *ComputeInstanceGroupManager) BuildResource() *schema.Resource {
 	costComponents, err := computeCostComponents(r.Region, r.MachineType, r.PurchaseOption, r.TargetSize, nil)
 	if err != nil {
-		logging.Logger.Warnf("Skipping resource %s. %s", r.Address, err)
+		logging.Logger.Warn().Msgf("Skipping resource %s. %s", r.Address, err)
 		return nil
 	}
 
